<?php
/**
* 饹륤󥿡ե
*
* PHP version 5
*
* @package    interfaces
* @author     stk2k <stk2k@sazysoft.com>
* @copyright  2008 stk2k, sazysoft
*/

interface IClassLoader extends IObject
{
	/*
	 * 饹
	 */
	public static function loadClass( String $class_name );

}

return __FILE__;